# Introduction

This is a library for producing gorgeous html reports from AppThreat scan results. Compatible with SARIF and grafeas format.

## Installation

```bash
pip install appthreat-scan-reports
```

## Usage

This package is internally used by [sast-scan](http://github.com/AppThreat/sast-scan), a free open-source Static Analysis Security Testing tool.
